'use strict';

var react = require('react');

/**
 * Improvement on top of React.lazy() that allows lazy rendering of named imports
 * Usage:
 *
 *  -- alternative to import { primary } from './Button'
 *  const PrimaryButton = lazier(() => import('./Button'), 'primary');
 *
 *  -- get the default import
 *  lazier(() => import('./Button'), 'default');
 *
 *  -- or
 *  lazier(() => import('./Button'));
 *
 */
/**
 * @param {() => Promise<*>} thenable
 * @param {String} name
 */

var lazier = function lazier(thenable) {
  var name = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'default';
  return react.lazy(function () {
    return thenable().then(function (mod) {
      return {
        "default": mod[name]
      };
    });
  });
};

module.exports = lazier;
//# sourceMappingURL=react-lazy-named.js.map
